'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.removeEntities = exports.removeEntity = exports.cancelQuery = exports.mutateAsync = exports.requestAsync = exports.mutateFailure = exports.mutateSuccess = exports.mutateStart = exports.requestFailure = exports.requestSuccess = exports.requestStart = undefined;

var _actionTypes = require('../constants/action-types');

var actionTypes = _interopRequireWildcard(_actionTypes);

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

var requestStart = exports.requestStart = function requestStart(url, body, request, meta, queryKey) {
    return {
        type: actionTypes.REQUEST_START,
        url: url,
        body: body,
        request: request,
        meta: meta,
        queryKey: queryKey
    };
};

var requestSuccess = exports.requestSuccess = function requestSuccess(url, body, status, entities, meta, queryKey) {
    return {
        type: actionTypes.REQUEST_SUCCESS,
        url: url,
        body: body,
        status: status,
        entities: entities,
        meta: meta,
        queryKey: queryKey,
        time: Date.now()
    };
};

var requestFailure = exports.requestFailure = function requestFailure(url, body, status, responseBody, meta, queryKey) {
    return {
        type: actionTypes.REQUEST_FAILURE,
        url: url,
        body: body,
        status: status,
        responseBody: responseBody,
        meta: meta,
        queryKey: queryKey,
        time: Date.now()
    };
};

var mutateStart = exports.mutateStart = function mutateStart(url, body, request, optimisticEntities, queryKey) {
    return {
        type: actionTypes.MUTATE_START,
        url: url,
        body: body,
        request: request,
        optimisticEntities: optimisticEntities,
        queryKey: queryKey
    };
};

var mutateSuccess = exports.mutateSuccess = function mutateSuccess(url, body, status, entities, queryKey) {
    return {
        type: actionTypes.MUTATE_SUCCESS,
        url: url,
        body: body,
        status: status,
        entities: entities,
        queryKey: queryKey,
        time: Date.now()
    };
};

var mutateFailure = exports.mutateFailure = function mutateFailure(url, body, status, originalEntities, queryKey) {
    return {
        type: actionTypes.MUTATE_FAILURE,
        url: url,
        body: body,
        status: status,
        originalEntities: originalEntities,
        queryKey: queryKey,
        time: Date.now()
    };
};

var requestAsync = exports.requestAsync = function requestAsync(_ref) {
    var body = _ref.body,
        force = _ref.force,
        queryKey = _ref.queryKey,
        meta = _ref.meta,
        options = _ref.options,
        retry = _ref.retry,
        transform = _ref.transform,
        update = _ref.update,
        url = _ref.url;

    return {
        type: actionTypes.REQUEST_ASYNC,
        body: body,
        force: force,
        queryKey: queryKey,
        meta: meta,
        options: options,
        retry: retry,
        transform: transform,
        update: update,
        url: url
    };
};

var mutateAsync = exports.mutateAsync = function mutateAsync(_ref2) {
    var body = _ref2.body,
        optimisticUpdate = _ref2.optimisticUpdate,
        options = _ref2.options,
        queryKey = _ref2.queryKey,
        transform = _ref2.transform,
        update = _ref2.update,
        url = _ref2.url;

    return {
        type: actionTypes.MUTATE_ASYNC,
        body: body,
        optimisticUpdate: optimisticUpdate,
        options: options,
        queryKey: queryKey,
        transform: transform,
        update: update,
        url: url
    };
};

var cancelQuery = exports.cancelQuery = function cancelQuery(queryKey) {
    return {
        type: actionTypes.CANCEL_QUERY,
        queryKey: queryKey
    };
};

var removeEntity = exports.removeEntity = function removeEntity(path) {
    return {
        type: actionTypes.REMOVE_ENTITY,
        path: path
    };
};

var removeEntities = exports.removeEntities = function removeEntities(paths) {
    return {
        type: actionTypes.REMOVE_ENTITIES,
        paths: paths
    };
};